@@ -9,9 +9,7 @@ dpkg-checkbuilddeps -d 'python3-apt, apt-btrfs-snapshot, parsewiki, python-feedp
 			python3-mock, xvfb, gir1.2-gtk-3.0, python3-gi, python3-nose, pep8, python3-distutils-extra'
 
 # update demotions
-(cd utils && ./demotions.py utopic vivid > demoted.cfg)
-# update demotions
-(cd utils && ./demotions.py trusty vivid > demoted.cfg.trusty)
+(cd utils && ./demotions.py vivid wily > demoted.cfg)
 # when this gets enabled, make sure to add symlink in DistUpgrade
 #(cd utils && ./demotions.py trusty w00t > demoted.cfg.trusty)
 
@@ -46,5 +44,5 @@ nosetests3
 rm -f ./tests/data-sources-list-test/apt.log
 
 # update version
-DEBVER=$(LC_ALL=C dpkg-parsechangelog |sed -n -e '/^Version:/s/^Version: //p' | sed 's/.*://')
+DEBVER=$(LC_ALL=C dpkg-parsechangelog |sed -n -e '/^Version:/s/^Version: //p' | sed s/.*://)
 echo "VERSION = '$DEBVER'" > DistUpgrade/DistUpgradeVersion.py
